==> netbeans_6.5.orig.tar.gz: netbeans-6.5/editor/test/qa-functional/src/org/netbeans/test/editor/suites/StableSuite.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2008 Sun Microsystems, Inc.
 */

package org.netbeans.test.editor.suites;

import junit.framework.Test;
import org.netbeans.junit.NbModuleSuite;
import org.netbeans.test.editor.general.GeneralTypingTest;
import org.netbeans.test.editor.popup.MainMenuTest;
import org.netbeans.test.editor.search.IncrementalSearchTest;
import org.netbeans.test.editor.search.ReplaceTest;
import org.netbeans.test.editor.suites.abbrevs.AbbreviationsAddRemovePerformer;

/**
 *
 * @author Jiri Prox
 */
public class StableSuite {

    public static Test suite() {
        return NbModuleSuite.create(
                NbModuleSuite.createConfiguration(GeneralTypingTest.class)
                .addTest(GeneralTypingTest.class,
                         "testJavaEnterBeginAndEnd")
                .addTest(MainMenuTest.class,
                         "testMainMenu")
                .addTest(IncrementalSearchTest.class,
                         //"testSearchForward",  //failing on windows -> removing from stable suite
                         //"testSearchBackwards",
                         "testMatchCase",
                         "testNextButton",
                         "testPrevButton",
                         "testCloseButton",
                         "testNotFound",
                         "testInvalidRegexp",
                         "testSearchForwardBackward",
                         //"testWholeWords",
                         "testRegularExpression",
                         "testFindNext",
                         "testFindPrev")
                .addTest(ReplaceTest.class)
                //.addTest(AbbreviationsAddRemovePerformer.class) // unstable
                );
    }
}

==> netbeans_6.8.orig.tar.gz: netbeans-6.8/editor/test/qa-functional/src/org/netbeans/test/editor/suites/StableSuite.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2008 Sun Microsystems, Inc.
 */

package org.netbeans.test.editor.suites;

import junit.framework.Test;
import org.netbeans.junit.NbModuleSuite;
import org.netbeans.test.editor.general.GeneralTypingTest;
import org.netbeans.test.editor.popup.MainMenuTest;
import org.netbeans.test.editor.search.IncrementalSearchTest;
import org.netbeans.test.editor.search.ReplaceTest;
import org.netbeans.test.editor.suites.abbrevs.AbbreviationsAddRemovePerformer;
import org.netbeans.test.editor.suites.keybindings.KeyMapTest;

/**
 *
 * @author Jiri Prox
 */
public class StableSuite {

    public static Test suite() {
        return NbModuleSuite.create(
                NbModuleSuite.createConfiguration(GeneralTypingTest.class)
                .addTest(GeneralTypingTest.class, "testJavaEnterBeginAndEnd")
                .addTest(MainMenuTest.class, "testMainMenu")
                .addTest(IncrementalSearchTest.class,
                         //"testSearchForward",  //failing on windows -> removing from stable suite
                         //"testSearchBackwards",
                         "testMatchCase",
                         "testNextButton",
                         "testPrevButton",
                         "testCloseButton",
                         "testNotFound",
                         "testInvalidRegexp",
                         "testSearchForwardBackward",
                         //"testWholeWords",
                         "testRegularExpression",
                         "testFindNext",
                         "testFindPrev")
                .addTest(ReplaceTest.class)
                .addTest(KeyMapTest.class, "prepareFileInEditor")
                .addTest(KeyMapTest.class, "testVerify")
                .addTest(KeyMapTest.class, "testAddDuplicateCancel")
                .addTest(KeyMapTest.class, "testAddShortcut")
                .addTest(KeyMapTest.class, "testUnassign")
                .addTest(KeyMapTest.class, "testAssignAlternativeShortcut")
                //.addTest(KeyMapTest.class, "testProfileRestore")//fails due to issue 151254
                .addTest(KeyMapTest.class, "testProfileDuplicte")
                .addTest(KeyMapTest.class, "testHelp")
                .addTest(KeyMapTest.class, "closeProject").clusters(".*").enableModules(".*")
                //.addTest(AbbreviationsAddRemovePerformer.class) // unstable
                );
    }
}
